#
# spec file for package moe
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           moe
Version:        1.10
Release:        10.6
Summary:        A Text Editor
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://www.gnu.org/software/moe/moe.html
Source:         https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.lz
Source1:        https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.lz.sig
Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=moe&download=1#/%{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libstdc++-devel
BuildRequires:  lzip
BuildRequires:  make
BuildRequires:  ncurses-devel
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
GNU Moe is an 8-bit clean, console text editor for ISO-8859 and ASCII
character encodings. It has a modeless interface, online help,
multiple windows, unlimited undo/redo capability, unlimited line length, global
search/replace (on all buffers at once), block operations, automatic
indentation, word wrapping, file name completion, directory browser, duplicate
removal from prompt histories, delimiter matching, text conversion from/to
UTF-8 and romanization.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags} CXXFLAGS="%{optflags}"

%install
%make_install install-man

%post
%install_info --info-dir=%{_infodir} %{_infodir}/moe.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/moe.info%{ext_info}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%config(noreplace) %{_sysconfdir}/moerc
%{_bindir}/moe
%{_infodir}/moe.info%{?ext_info}
%{_mandir}/man1/moe.1%{?ext_man}

%changelog
* Fri Jan  4 2019 astieger@suse.com
- GNU moe 1.10:
  * The default right margin has been changed from 72 to 76.
  * The new command 'C-o k' (capitalize words in block) has been
    added. It uppercases the first letter of each word and
    lowercases the rest.
  * The new command 'C-s p' (show line position in buffer) has
    been added. It shows on the status line the percent position
    of the current line in the buffer.
  * Recursive load now ignores some non-text files by extension
  * Infinite replacement loops are now detected.
  * 'C-q c' (exit without saving) and 'C-q x' (save and exit) now
    exit much faster when editing many files (thousands).
  * 'C-q x' (save and exit) now does not delete any buffer handles
    until all modified buffers have been succesfully saved. And
    shows "Read only" without asking for a name if a modified
    unnamed read-only buffer is found.
  * The UTF-8 decoder now converts some more characters.
  * Showing the contents of a directory no longer alters the
    position of the top line of the buffers menu.
  * The buffers menu is now shown even if there is only one buffer
  * When showing the contents of a directory, ".." is now put
    always first even if some file precede it in ASCIIbetical order
  * On buffers larger than 1000 lines, bookmarks 1 to 9 are now set
    at 10%% to 90%% of the buffer size in lines
* Mon Mar 19 2018 jengelh@inai.de
- Ensure neutrality of description.
* Sun Mar 18 2018 avindra@opensuse.org
- GNU moe 1.9:
  * rc.cc: Load recursively all regular files in each directory
    passed in the command line.
  * Added a new help key 'C-a'.
  * encoding.cc: UTF-8 decoder now converts some more characters.
  * buffer_handle.h (Buffer_handle): Adjust '+line,col' for tabs.
  * set_to_matching_delimiter: Skip delimiters inside /**/ comments.
  * Added 'N' command to the basic less emulation.
  * rc.cc (process_options): Don't use stdin more than once.
  * window_vector.cc (remove_duplicate_lines): Run 20%% faster.
  * Cut long filenames in messages like "File '...filename' saved".
  * Set an 8-bit "C" locale in Cygwin to show chars > 127.
  * configure: Avoid warning on some shells when testing for g++.
  * Makefile.in: Detect the existence of install-info.
- cleanup with spec-cleaner
* Sun Jul 10 2016 mpluskal@suse.com
- Small spec file cleanup
* Sun Mar  6 2016 astieger@suse.com
- GNU moe 1.8:
  * Moe is now able to read some types of non regular files at
    startup. Opening non regular files during the editing session
    is not allowed because it could cause moe to be killed, losing
    the changes of any other files being edited.
  * "Center line" now works correctly in overwrite mode.
* Fri May  8 2015 astieger@suse.com
- GNU moe 1.7
- complete package overhaul
* Fri Sep  4 2009 pascal.bleser@opensuse.org
- update to 1.3
* Mon Feb 23 2009 guru@unixtech.be
- moved to openSUSE Build Service
- update to 1.1
* Wed Jan 17 2007 guru@unixtech.be
- new upstream version
* Fri Apr 21 2006 guru@unixtech.be
- new package
